import 'dart:io';

import 'package:workouttest_util/util/logging.dart';
import 'package:flutter/cupertino.dart';
import 'package:shared_preferences/shared_preferences.dart';

class AppLanguage with Logging {
  static final AppLanguage _singleton = AppLanguage._internal();

  Locale? _appLocale = const Locale('en');

  factory AppLanguage() {
    return _singleton;
  }

  AppLanguage._internal();

  static Future<AppLanguage> getInstance() async {
    return _singleton;
  }

  Locale get appLocal => _appLocale ?? const Locale("en");

  Future<void> fetchLocale() async {
    var prefs = await SharedPreferences.getInstance();
    String? langCode = prefs.getString('language_code');
    log(" ---- lang code $langCode");
    if (langCode == null) {
      _appLocale = const Locale('en');
    } else {
      _appLocale = Locale(langCode);
    }
    log(" ---- Fetched lang: $_appLocale");
  }

  getLocale(SharedPreferences prefs) {
    String? langCode = prefs.getString('language_code');
    if (langCode == null) {
      final String localName = Platform.localeName;
      if (localName.endsWith("HU")) {
        _appLocale = const Locale('hu');
        langCode = "hu";
      } else {
        _appLocale = const Locale('en');
        langCode = "en";
      }
    }
    _appLocale = Locale(langCode);
    log(" ---- Get lang: $_appLocale lang code $langCode");
  }

  void changeLanguage(Locale type) async {
    var prefs = await SharedPreferences.getInstance();
    if (_appLocale == type) {
      return;
    }
    if (type == const Locale("hu")) {
      _appLocale = const Locale("hu");
      await prefs.setString('language_code', 'hu');
      await prefs.setString('countryCode', 'HU');
    } else {
      _appLocale = const Locale("en");
      await prefs.setString('language_code', 'en');
      await prefs.setString('countryCode', 'US');
    }
    log(" ---- Stored lang: $_appLocale");
  }
}
